#! /usr/bin/python2

## Copyright (C) 2002, 2012 Red Hat, Inc.
## Copyright (C) 2002, 2012 Than Ngo <than@redhat.com>

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

PROGNAME = 'system-switch-displaymanager'
TITLE = PROGNAME
SWITCHMAILDIR = '/usr/share/' + PROGNAME + '/'
COPYRIGHT = 'Copyright (C) 2002-2012 Red Hat, Inc.'
AUTORS = ['Than Ngo <than@redhat.com>']
VERSION = '1.5.1-1'
GLADEPATH = ''
TRUE = (1==1)
FALSE = not TRUE

import re
import traceback
import sys
import os
import os.path
import shutil
import string
import gettext

##
## I18N
##
gettext.bindtextdomain(PROGNAME, '/usr/share/locale')
gettext.textdomain(PROGNAME)
_ = gettext.gettext

TEXT = _('The Display Manager Switcher is a tool which enables users to easily switch between various graphical Display Managers that they have installed.\n\nPlease select the default display manager for the system.')

INFO_TEXT = _('Your display manager has successfully been switched,\n'
              'but you must restart the X Window System for the changes\n'
              'to take effect.\n')

WARNING_TEXT = _('Your graphical display manager cannot be switched, please make sure that the package system-switch-displaymanager has correctly been installed on the machine.\n')

HELPER = 'system-switch-displaymanager-helper'

# switch login manager with systemctr in f18 oder later
SYSTEMD=1

DM_NAME=0
WIDGET_NAME=1
OPTION_NAME=2
ICON_NAME=3

KDM = 'KDE'
GDM = 'GDM'
XDM = 'XDM'
WDM = 'WDM'
LIGHTDM = 'LIGHTDM'
LXDM = 'LXDM'
SDDM = 'SDDM'

DISPLAYMANAGERS={ KDM         : [ 'kdm', 'kdmRB', 'KDE', 'kdm.png' ],
                  GDM         : [ 'gdm', 'gdmRB', 'GDM', 'gdm.png' ],
                  XDM         : [ 'xdm', 'xdmRB', 'XDM', 'xdm.png' ],
                  WDM         : [ 'wdm', 'wdmRB', 'WDM', 'wdm.png' ],
                  LIGHTDM     : [ 'lightdm', 'lightdmRB', 'LIGHTDM', 'lightdm.png' ],
                  LXDM        : [ 'lxdm', 'lxdmRB', 'LXDM', 'lxdm.png' ],
                  SDDM        : [ 'sddm', 'sddmRB', 'SDDM', 'sddm.png' ]
                }

def getValue( s ):
    if string.find( s, '=' ) < 0:
        return ''
    s = string.split( s, '=', 1 )[1]
    s = string.replace( s, '\"', '')

    return string.strip(s)

def getSystemDefault():
    service_file = '/etc/systemd/system/display-manager.service'
    dm = ''
    if os.access( service_file, os.F_OK ):
       dm = os.path.splitext( os.path.basename(os.readlink( service_file ) ) )[0].upper()
    return dm

def updateList():
    dm = getSystemDefault()
    if dm in DISPLAYMANAGERS.keys():
       DISPLAYMANAGERS[SYSTEM][ICON_NAME] = DISPLAYMANAGERS[dm][ICON_NAME]

def checkDM( dm ):
    DESKTOP_PATH = [ '/usr/bin/', '/usr/sbin/', '/usr/X11R6/bin/', '/usr/local/bin/', '/usr/local/sbin/' ]

    for p in DESKTOP_PATH:
        if os.access( p + DISPLAYMANAGERS[dm][DM_NAME], os.X_OK ):
            return TRUE

    return FALSE

def getDMList():
    dmlist = []
    for dm in DISPLAYMANAGERS.keys():
        if checkDM( dm ):
           dmlist.append( dm )
    return dmlist

def getCurrentDM():
    return getSystemDefault()

DMLIST = getDMList()
DM = getCurrentDM()

def getDefaultDM():
    dm = DMLIST[0]
    if KDM in DMLIST:
       dm = KDM

    return dm

def switchDM( dm ):
    pass
